(* $Id: godi_plist.mli 493 2004-09-29 15:57:17Z gerd $
 * ----------------------------------------------------------------------
 * Copyright 2004 by Gerd Stolpmann.
 *
 * This file is part of godi-tools.
 *
 * godi-tools is free software; you can redistribute it and/or modify it
 * under the conditions in the file LICENSE.
 *
 * godi-tools is distributed WITHOUT ANY WARRANTY, as detailed in the
 * file LICENSE.
 *)

(** Parsing and printing of PLIST files *)

type inst_plist_element =
    [ `Name of string    (* name plus full version string *)
    | `Cwd of string
    | `Src of string
    | `Pkgdep of Godi_versions.dependency
    | `Blddep of Godi_versions.dependency
    | `Pkgcfl of Godi_versions.dependency
    | `Dirrm of string
    | `File of string * string option   (* file name, checksum *)
    | `Comment of string
    | `Exec of string
    | `Unexec of string
    | `Display of string
    | `Option of [ `Extract_in_place | `Preserve ]
    | `Ignore
    | `Unsupported of string * string
	 (* @mode, @owner, @group, @mtree, @ignore_inst *)
    ]
  (** An [inst_plist_element] represents a line in the +CONTENTS file, i.e.
   * the variant of PLIST used in binary packages.
   *)

exception Plist_error of string * string
  (** The first string is the file name, the second string the errorneous
   * line.
   *)

val parse_inst_plist : ?no_files:bool -> string -> inst_plist_element list
  (** Parses the file, and returns the list of directives contained in it.
   *
   * @param no_files If set to true, only [`Name], [`Cwd], [`Src],
   * [`Pkgdep], [`Blddep], [`Pkgcfl], [`Option] directives are returned.
   *)

val parse_inst_plist_string : ?no_files:bool -> string -> inst_plist_element list
  (** Parses the PLIST from the string value *)

val apply_ignore_directive : inst_plist_element list -> inst_plist_element list
  (** Applies the `Ignore directive, and returns the transformed list *)

val extract_package_name : inst_plist_element list -> string
  (** Extracts the package name. Raises Not_found if not found.
    * The name includes the full version string.
  *)


val print_inst_plist : string -> inst_plist_element list -> unit
